
'filesysobjects' - package
###########################

.. toctree::
   :maxdepth: 4

.. automodule:: filesysobjects

**Sources**

* `filesysobjects.FileSysObjects [source] <_modules/filesysobjects/FileSysObjects.html#>`_



.. include:: filesysobjects.rst

